/// <reference types="bn.js" />
import { BN } from "@project-serum/anchor";
import { PublicKey } from "@solana/web3.js";
import { TransactionBuilder } from "@orca-so/common-sdk";
import { Context, PDA } from "..";
import { PropertyData, TokenClaimedEventData, TokenPurchasedEventData, UiLockerData, UiPropertyData, UiTokenClaimedEventData, UiTokenPurchasedEventData, UiVestingData } from "../types";
import BigNumber from "bignumber.js";
export declare class PropertyClient {
    ctx: Context;
    propertyMintAccount: PublicKey;
    propertyData: PropertyData;
    uiPropertyData: UiPropertyData;
    pda: PDA;
    constructor(ctx: Context, propertyMintAccount: PublicKey, propertyData: PropertyData, uiPropertyData: UiPropertyData, pda: PDA);
    static getProperty(ctx: Context, propertyMintAccount: PublicKey): Promise<PropertyClient>;
    static new(ctx: Context, admin: PublicKey, propertyMintAccount: PublicKey, privateSaleStartTime: BN, privateSaleEndTime: BN, privateSaleSupplyAmount: BN, privateSaleTokenPrice: BN, privateSaleMinimumPurchaseAmount: BN, privateSaleCommissionAmount: BN, privateSaleReferralCommissionAmount: BN, privateSaleDiscountPercentage: number, privateSaleTgePercentage: number, privateSaleUnlockPeriod: BN, privateSaleUnlockDuration: BN, privateSaleMinimumPlatformAmount: BN, publicSaleStartTime: BN, publicSaleEndTime: BN, publicSaleSupplyAmount: BN, publicSaleTokenPrice: BN, publicSaleMinimumPurchaseAmount: BN, publicSaleCommissionAmount: BN, publicSaleCommissionBoostAmount: BN, publicSaleReferralCommissionAmount: BN, publicSaleReferralCommissionBoostAmount: BN, publicSaleReferralCommissionBoostThreshold: BN): Promise<TransactionBuilder>;
    update(ctx: Context, admin: PublicKey, propertyMintAccount: PublicKey, privateSaleStartTime: BN, privateSaleEndTime: BN, privateSaleSupplyAmount: BN, privateSaleTokenPrice: BN, privateSaleMinimumPurchaseAmount: BN, privateSaleCommissionAmount: BN, privateSaleReferralCommissionAmount: BN, privateSaleDiscountPercentage: number, privateSaleTgePercentage: number, privateSaleUnlockPeriod: BN, privateSaleUnlockDuration: BN, privateSaleMinimumPlatformAmount: BN, publicSaleStartTime: BN, publicSaleEndTime: BN, publicSaleSupplyAmount: BN, publicSaleTokenPrice: BN, publicSaleMinimumPurchaseAmount: BN, publicSaleCommissionAmount: BN, publicSaleCommissionBoostAmount: BN, publicSaleReferralCommissionAmount: BN, publicSaleReferralCommissionBoostAmount: BN, publicSaleReferralCommissionBoostThreshold: BN): Promise<TransactionBuilder>;
    withdrawToken(ctx: Context, admin: PublicKey, propertyMintAccount: PublicKey, withdrawMintAccount: PublicKey, beneficiary: PublicKey, amount: BN): Promise<TransactionBuilder>;
    purchasePropertyToken(purchaseAmount: BigNumber, referrer?: PublicKey): Promise<TransactionBuilder>;
    claimPropertyToken(): Promise<TransactionBuilder>;
    claimPublicSalePropertyToken(): Promise<TransactionBuilder>;
    grantBurnRole(ctx: Context, burner: PublicKey): Promise<TransactionBuilder>;
    revokeBurnRole(ctx: Context, burner: PublicKey): Promise<TransactionBuilder>;
    updateBurnConfig(ctx: Context, mint: PublicKey, amountPerPeriod: BN, period: BN): Promise<TransactionBuilder>;
    swapAndBurn(ctx: Context, mint: PublicKey, isTesting?: boolean): Promise<TransactionBuilder>;
    burnerUpdateBurnConfig(ctx: Context, mint: PublicKey, amountPerPeriod: BN, period: BN): Promise<TransactionBuilder>;
    getLocker(): Promise<UiLockerData>;
    getVesting(): Promise<UiVestingData | null>;
    getCommissionAmount(purchaseAmount: BigNumber, hasReferral?: boolean): BigNumber;
    convertTokenPurchasedEventDataToUiData(eventData: TokenPurchasedEventData): Promise<UiTokenPurchasedEventData>;
    convertTokenClaimedEventDataToUiData(eventData: TokenClaimedEventData): Promise<UiTokenClaimedEventData>;
    refresh(): Promise<PropertyClient>;
}
