import { Connection } from "@solana/web3.js";
import { Address } from "@project-serum/anchor";
import { LockerData, PlatformData, PropertyData, BurnData, BurnRoleData, VestingData } from "../";
import { ParsableEntity, ParsableProperty } from "./parsing";
/**
 * Supported accounts
 */
type CachedValue = ParsableProperty;
/**
 * Include both the entity (i.e. type) of the stored value, and the value itself
 */
interface CachedContent<T extends CachedValue> {
    entity: ParsableEntity<T>;
    value: CachedValue | null;
}
export declare class AccountFetcher {
    private readonly connection;
    private readonly _cache;
    private _tokenAccountRentExempt;
    constructor(connection: Connection, cache?: Record<string, CachedContent<CachedValue>>);
    /*** Public Methods ***/
    /**
     * Retrieve minimum balance for rent exemption of a Token Account;
     *
     * @param refresh force refresh of account rent exemption
     * @returns minimum balance for rent exemption
     */
    getTokenAccountRentExempt(refresh?: boolean): Promise<number>;
    /**
     * Update the cached value of all entities currently in the cache.
     * Uses batched rpc request for network efficient fetch.
     */
    refreshAll(): Promise<void>;
    /*** Private Methods ***/
    /**
     * Retrieve from cache or fetch from rpc, an account
     */
    private get;
    /**
     * Retrieve from cache or fetch from rpc, a list of accounts
     */
    private list;
    /**
     * Make batch rpc request
     */
    private bulkRequest;
    getPlatform(address: Address, refresh?: boolean): Promise<PlatformData | null>;
    getProperty(address: Address, refresh?: boolean): Promise<PropertyData | null>;
    getLocker(address: Address, refresh?: boolean): Promise<LockerData | null>;
    getVesting(address: Address, refresh?: boolean): Promise<VestingData | null>;
    getBurnRole(address: Address, refresh?: boolean): Promise<BurnRoleData | null>;
    getBurn(address: Address, refresh?: boolean): Promise<BurnData | null>;
}
export {};
